@@ -138,6 +138,31 @@ PKGPATH=www/ap2-python
 pkg_src_summary -m --fields PKGNAME,PKGPATH www/ap2-python:PKG_APACHE=apache2 |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #3' \
+'ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=31
+PKGNAME=ap2-py31-python-3.3.1
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=27
+PKGNAME=ap2-py27-python-3.3.1
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PKG_APACHE=apache2
+PKGNAME=ap2-py26-python-3.3.1
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=25
+PKGNAME=ap2-py25-python-3.3.1
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PKG_APACHE=apache2,PYTHON_VERSION_REQD=24
+PKGNAME=ap2-py24-python-3.3.1
+PKGPATH=www/ap2-python
+
+'
+
+pkg_src_summary -m --fields PKGNAME,PKGPATH www/ap2-python:PKG_APACHE=apache22 |
+grep -v DEPENDS |
+cmp 'pkg_src_summary #3.1' \
 'ASSIGNMENTS=PYTHON_VERSION_REQD=31
 PKGNAME=ap22-py31-python-3.3.1
 PKGPATH=www/ap2-python
@@ -162,6 +187,19 @@ PKGPATH=www/ap2-python
 pkg_src_summary -m --fields='PKGNAME PKGPATH' www/ap2-python:PYTHON_VERSION_REQD=25 |
 grep -v DEPENDS |
 cmp 'pkg_src_summary #4' \
+'ASSIGNMENTS=PYTHON_VERSION_REQD=25,PKG_APACHE=apache2
+PKGNAME=ap2-py25-python-3.3.1
+PKGPATH=www/ap2-python
+
+ASSIGNMENTS=PYTHON_VERSION_REQD=25
+PKGNAME=ap22-py25-python-3.3.1
+PKGPATH=www/ap2-python
+
+'
+
+pkg_src_summary -m --fields='PKGNAME PKGPATH' www/ap2-python:PYTHON_VERSION_REQD=26 |
+grep -v DEPENDS |
+cmp 'pkg_src_summary #4.1' \
 'ASSIGNMENTS=PKG_APACHE=apache2
 PKGNAME=ap2-py26-python-3.3.1
 PKGPATH=www/ap2-python
@@ -373,10 +411,27 @@ hide_distfile_size (){
     sed 's/:[0-9]*/:NNN/g' "$@"
 }
 
-pkg_src_summary -f PKGNAME,PKGPATH,ALLDISTFILES x11/xxkb | hide_distfile_size |
+pkg_src_summary -f PKGNAME,PKGPATH,ALLDISTFILES x11/xxkb |
+hide_distfile_size | normalize_version |
 cmp 'pkg_src_summary #17' \
-'PKGNAME=xxkb-1.11
+'PKGNAME=xxkb-X
 PKGPATH=x11/xxkb
-ALLDISTFILES= xxkb-1.11-src.tar.gz:NNN
+ALLDISTFILES=xxkb-1.11-src.tar.gz:NNN 
 
 '
+
+pkg_src_summary -f PKGNAME,PKGPATH,BUILD_DEPENDS -b x11/xxkb |
+awk '/^BUILD_DEPENDS=.*digest/ {print "ok"}
+     /^BOOTSTRAP_DEPENDS=/ {print "bad"} ' |
+cmp 'pkg_src_summary #18' \
+'ok
+'
+
+pkg_src_summary -f PKGNAME,PKGPATH,ALLDISTFILES devel/bmake |
+hide_distfile_size | normalize_version |
+cmp 'pkg_src_summary #19' \
+'PKGNAME=bmake-X
+PKGPATH=devel/bmake
+
+'
+
